/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIClipboardDragDropHooks;
interface nsISimpleEnumerator;


/**
 * Please note that the following api is not intended for embedders;
 * it is intended as an internal (to gecko).  Embedders can indirectly
 * call these by sending commands (see description in 
 * nsIClipboardDragDropHooks.idl).
 *
 * Internal gecko usage is accomplished by calling get_Interface on a
 * docshell.
 */


// 876A2015-6B66-11D7-8F18-0003938A9D96
[scriptable,uuid(876A2015-6B66-11D7-8F18-0003938A9D96)]
interface nsIClipboardDragDropHookList : nsISupports
{
  /**
   * Add a hook to list.
   * @param aHooks  implementation of hooks
   */
  void addClipboardDragDropHooks(in nsIClipboardDragDropHooks aHooks);

  /**
   * Remove a hook from list (note if this implementation is not present
   * in the list then removal will be ignored).
   * @param aHooks  implementation of hooks
   */
  void removeClipboardDragDropHooks(in nsIClipboardDragDropHooks aHooks);

  /**
   * Gets an enumerator for all hooks which have been added.
   * @return nsISimpleEnumerator for nsIClipboardDragDropHooks
   */
  nsISimpleEnumerator getHookEnumerator();
};

